import React from 'react';
import { ComponentPropsWithMetadata } from '@highlight-ui/utils-commons';
export interface ToggleProps extends ComponentPropsWithMetadata {
    /**
     * Determines whether the Toggle is currently switched on or off
     */
    checked: boolean;
    /**
     * Callback invoked when the user switches the Toggle on or off
     */
    onToggle: () => void;
    /**
     * Determines whether the Toggle should render in a disabled state
     */
    disabled?: boolean;
    /**
     * An optional unique ID to link the form components.
     * If not supplied, a unique ID will be generated internally.
     */
    id?: string;
    /**
     * Allows providing a custom class name to the DIV element that surrounds the text
     */
    className?: string;
    /**
     * Optional title to be rendered beside the toggle.
     */
    title?: string;
    /**
     * Optional sub-title to be rendered underneath the title.
     * Cannot be rendered without a title.
     */
    subTitle?: string;
}
declare const Toggle: React.ForwardRefExoticComponent<ToggleProps & React.RefAttributes<HTMLLabelElement>>;
export default Toggle;
